@@ -12,6 +12,7 @@ import shutil
 import subprocess
 import sys
 import tempfile
+import warnings
 from itertools import chain
 
 import onnx
@@ -25,7 +26,7 @@ from llama_torch import setup_torch_model
 
 # to patch transformers before exporting for transformers >= 4.45
 from models.torch_export_patches import bypass_export_some_errors
-from models.torch_export_patches.patch_inputs import convert_dynamic_axes_into_dynamic_shapes, replace_dynamic_shapes
+from models.torch_export_patches.patch_inputs import convert_dynamic_axes_into_dynamic_shapes
 from onnx_model import OnnxModel
 from optimizer import optimize_model
 from packaging import version
@@ -126,7 +127,7 @@ def save_onnx_model(onnx_model: onnx.ModelProto, output_path: str, data_path: st
 def run_dynamo_export(
     args: argparse.Namespace, l_config: AutoConfig, llama: AutoModelForCausalLM, rank: int = 0, world_size: int = 1
 ):
-    from torch._dynamo import config
+    from torch._dynamo import config  # noqa: PLC0415
 
     config.capture_scalar_outputs = True
 
@@ -165,62 +166,18 @@ def run_dynamo_export(
         llama, args=model_args, dynamic_axes=dynamic_axes, prefix_mapping={"present": "past_key_values"}
     )
 
-    if version.Version(torch.__version__) < version.Version("2.7"):
-        # This section is only needed for torch==2.6. The workaround implemented here
-        # to fix bugs is not necessary with torch>=2.7.
-        # - strings are not allowed with torch 2.6, so we replace them by DYNAMIC
-        # - TypePromotion was fixed in torch==2.7
-        from onnxscript import opset18 as op
-
-        dynamic_shapes = replace_dynamic_shapes(
-            dynamic_shapes,
-            dict(batch_size=torch.export.Dim("batch_size")),
-            default_value=torch.export.Dim.DYNAMIC,
+    with bypass_export_some_errors(patch_transformers=True):
+        torch.onnx.export(
+            llama,
+            (),
+            temp_path,
+            kwargs=model_kwargs,
+            dynamic_shapes=dynamic_shapes,
+            dynamo=True,
+            verbose=args.verbose,
+            optimize=True,
         )
 
-        # TypePromotion cannot fix a type issue after the conversion.
-        # We insert an additional CastLike when the exporter
-        def custom_aten_ge(self, other):
-            if isinstance(other, (int, float)):
-                return op.GreaterOrEqual(self, op.CastLike(other, self))
-            return op.GreaterOrEqual(self, other)
-
-        with bypass_export_some_errors(patch_transformers=True):
-            # ONNX pass TypePromotion crashes for torch 2.6.
-            # It can be bypassed by exporting first into an exported program.
-            # We then need to apply run_decompositions() before onnx conversion starts.
-            ep = torch.export.export(
-                llama,
-                (),
-                kwargs=model_kwargs,
-                dynamic_shapes=dynamic_shapes,
-                strict=False,
-            )
-            ep = ep.run_decompositions()
-            torch.onnx.export(
-                ep,
-                (),
-                temp_path,
-                kwargs=model_kwargs,
-                dynamic_shapes=dynamic_shapes,
-                dynamo=True,
-                verbose=args.verbose,
-                optimize=True,
-                custom_translation_table={torch.ops.aten.ge.Scalar: custom_aten_ge},
-            )
-    else:
-        with bypass_export_some_errors(patch_transformers=True):
-            torch.onnx.export(
-                llama,
-                (),
-                temp_path,
-                kwargs=model_kwargs,
-                dynamic_shapes=dynamic_shapes,
-                dynamo=True,
-                verbose=args.verbose,
-                optimize=True,
-            )
-
     # Check decoder_with_past_model.onnx and save all external data to one file
     onnx.checker.check_model(temp_path)
     onnx.shape_inference.infer_shapes_path(temp_path)
@@ -448,7 +405,7 @@ def optimize_export(
     world_size: int = 1,
     window_size: int = -1,
 ):
-    from fusion_options import FusionOptions
+    from fusion_options import FusionOptions  # noqa: PLC0415
 
     optimization_options = FusionOptions("gpt2")
 
@@ -533,10 +490,10 @@ def smooth_quant(
     decoder_model_int8_path: str,
     decoder_with_past_model_int8_path: str,
 ):
-    from neural_compressor import PostTrainingQuantConfig, set_workspace
-    from neural_compressor import quantization as intel_quantization
-    from onnx.external_data_helper import load_external_data_for_model
-    from quant_kv_dataloader import QuantKVDataLoader
+    from neural_compressor import PostTrainingQuantConfig, set_workspace  # noqa: PLC0415
+    from neural_compressor import quantization as intel_quantization  # noqa: PLC0415
+    from onnx.external_data_helper import load_external_data_for_model  # noqa: PLC0415
+    from quant_kv_dataloader import QuantKVDataLoader  # noqa: PLC0415
 
     set_workspace(args.nc_workspace)
     quantization_config = PostTrainingQuantConfig(
@@ -675,7 +632,7 @@ def get_args():
         "--execution_provider",
         required=False,
         default="cpu",
-        choices=["cpu", "cuda", "rocm"],
+        choices=["cpu", "cuda"],
         help="Execution provider to verify parity with",
     )
 
@@ -714,6 +671,8 @@ def get_args():
 
     blockwise_group = parser.add_argument_group("blockwise (4-bit quantization)")
 
+    parser.add_argument("--bits", default=4, type=int, help="the target bits to represent weight")
+
     blockwise_group.add_argument(
         "--block_size",
         required=False,
@@ -843,6 +802,12 @@ def get_args():
 
 
 def main():
+    warnings.warn(
+        "This example is deprecated. Use the Olive recipe instead: "
+        "https://github.com/microsoft/olive-recipes/tree/main",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     if version.parse(torch.__version__) < version.parse("2.2.0"):
         logger.error(f"Detected PyTorch version {torch.__version__}. Please upgrade and use v2.2.0 or newer.")
         return
@@ -1032,6 +997,7 @@ def main():
                         model = onnx.load_model(fp_path, load_external_data=True)
                         quant = MatMulNBitsQuantizer(
                             model=model,
+                            bits=args.bits,
                             block_size=args.block_size,
                             is_symmetric=True,
                             accuracy_level=args.int4_accuracy_level,
